@@ -13,6 +13,7 @@ import shutil
 import threadpool
 import codecs
 import copy
+import glob2
 
 from .tools import *
 from .log import logger
@@ -29,6 +30,7 @@ class Component:
         self.type = ''
         self.version = ''
         self.depends = [] # [{'aos':'v7.3'},{'kv':'v7.4'}]
+        self.supported_boards = []
         self.description = ''
         self.historyVersion = {}
         self.updated = ''
@@ -265,6 +267,12 @@ class Component:
                 self.depends.append(d)
             elif type(d) == str:
                 self.depends.append({d: ""})
+        self.supported_boards = []
+        for d in pack.supported_boards:
+            if type(d) == dict:
+                self.supported_boards.append(d)
+            elif type(d) == str:
+                self.supported_boards.append({d: ""})
 
         # add component version in defconfig
         ver_key = "%s_SW_VERSION" % self.name.upper()
@@ -405,7 +413,7 @@ class Component:
 
             for src in ins['source']:
                 src = os.path.join(self.path, src)
-                for s in glob.iglob(src):
+                for s in glob2.iglob(src):
                     fn = os.path.basename(s)
                     ds = os.path.join(path, fn)
                     shutil.copy2(s, ds)
@@ -418,7 +426,7 @@ class Component:
 
             for src in ins['source']:
                 src = os.path.join(self.path, src)
-                for s in glob.iglob(src):
+                for s in glob2.iglob(src):
                     fn = os.path.basename(s)
                     ds = os.path.join(path, fn)
                     shutil.copy2(s, ds)
