@@ -11,6 +11,7 @@ from .tools import *
 from .log import logger
 from .yoc import YoC
 from .builder import *
+from .package import set_specified_board
 
 import warnings
 warnings.filterwarnings("ignore", category=SyntaxWarning)
@@ -53,6 +54,7 @@ class Make(object):
             pass
 
         board_name = SCons.GetOption('board')
+        set_specified_board(board_name)
         print_depends = False
         if not SCons.GetOption('verbose'):
             print_depends = True
