@@ -14,6 +14,7 @@ from .tools import *
 from .log import logger
 
 cur_compiler = 'gcc'
+specified_board = ''
 desc_width = 50
 
 
@@ -26,6 +27,15 @@ def get_compiler():
     global cur_compiler
     return cur_compiler
 
+# set by aos make -b <board>
+def set_specified_board(b):
+    global specified_board
+    specified_board = b
+
+def get_specified_board():
+    global specified_board
+    return specified_board
+
 
 class HardwareInfo:
     def __init__(self, dic):
@@ -327,6 +337,7 @@ class Package(object):
         self.license = ''
         self.homepage = ''
         self.depends = {}
+        self.supported_boards = {}
         self.build_config = build_config({})
         self.defconfig = {}
         self.source_file = []
@@ -409,6 +420,10 @@ class Package(object):
                 '%s: `type` field must be "solution" or "board" or "chip" or "arch" or "drv_core" or "drv_peripheral" or "drv_external_device" or "kernel" or "common" or "sdk" or "document".' % filename)
             exit(-1)
 
+        if self.type == 'solution':
+            board = get_specified_board()
+            if board:
+                self.hw_info.board_name = board
         text = self.hw_info.check(self.type)
 
         if text:
