@@ -12,6 +12,22 @@ from .tools import *
 from .package import *
 from .component import *
 
+try:
+    try:
+        import SCons.Script as SCons
+    except:
+        import scons
+        for path in scons.__path__:
+            sys.path.append(path)
+            import SCons.Script as SCons
+except:
+    scons_path = []
+    for path in sys.path:
+        if os.path.isdir(os.path.join(path, "scons")):
+            scons_path.append(os.path.join(path, "scons"))
+    if scons_path:
+        sys.path += scons_path
+        import SCons.Script as SCons
 
 class Variables:
     def __init__(self):
@@ -27,6 +43,27 @@ class Variables:
         if var in self.vars:
             return self.vars[var]
 
+    def check_variable(self, values=[]):
+        # check and condition: [v1, v2, v3...], AND operation
+        new_values = []
+        for v in values:
+            v = v.strip()
+            if v:
+                new_values.append(v)
+        if not new_values:
+            return False
+        for v in new_values:
+            if(v.startswith('!')):
+                a = self.get(v[1:])
+                if str(a) not in ['n', 'no', 'f', 'false', '0', False, 0, 'None']:
+                    return False
+            else:
+                a = self.get(v)
+                if str(a) not in ['y', 'yes', 't', 'true', '1', True, 1]:
+                    return False
+
+        return True
+
     def convert(self, var):
         if var == None or len(var) == 0:
             return None
@@ -35,17 +72,11 @@ class Variables:
         if len(v) > 1:
             x = re.search('<(.+?)>', v[1], re.M | re.I)
             if x:
-                x = x.group(1).strip()
-                if(x.startswith('!')):
-                    x = self.get(x[1:])
-                    if str(x) not in ['n', 'no', 'f', 'false', '0', False, 0, 'None']:
-                        return None
+                x = x.group(1).split(',')
+                if self.check_variable(x):
                     var = v[0].strip()
                 else:
-                    x = self.get(x)
-                    if str(x) not in ['y', 'yes', 't', 'true', '1', True, 1]:
-                        return None
-                    var = v[0].strip()
+                    return None
 
         x = re.findall('<(.+?)>', var)
         for key in x:
@@ -208,6 +239,20 @@ class Solution:
                 self.defines[k] = v
                 self.org_defines[k] = v
 
+        def update_defines_from_cmdline(component):
+            for k, v in SCons.ARGLIST:
+                if k != 'V' and k != 'BOARD':
+                    if str.isdigit(v):
+                        v = int(v)
+                        if not SCons.GetOption('verbose'):
+                            put_string("%s is number %d" % (k, v))
+                    else:
+                        if not SCons.GetOption('verbose'):
+                            put_string("%s is str %s" % (k, v))
+                    self.variables.set(k, v)
+                    self.defines[k] = v
+                    self.org_defines[k] = v
+
         def update_variables():
             # copy defines
             for component in self.components:
@@ -231,6 +276,7 @@ class Solution:
             for component in self.components:
                 if component.type == 'solution':
                     add_defines(component)
+                    update_defines_from_cmdline(component)
 
             solution_hw_info = HardwareInfo({})
             for component in [self.chip_component, self.board_component, self.solution_component]:
