@@ -41,7 +41,18 @@ Make aos program.\n"
         params_str = " ".join(params)
         # get workspace root directory
         conf = Configure()
-        change_dir_to_solution(conf.yoc_path)
+        cur_dir = os.getcwd()
+        # enter into solution directory if in the workspace root directory
+        if cur_dir == conf.yoc_path:
+            solution, board = getSolutionAndBoard(conf.yoc_path)
+            if solution:
+                new_dir = os.path.join(cur_dir, "solutions", solution)
+                if os.path.isdir(new_dir):
+                    os.chdir(new_dir)
+                    put_string("change dir to %s." % new_dir)
+            if board:
+                # read board from .config, and set to opt.board. Like aos make -b board
+                opt.board = board
 
         ext_scons_existed = False
         if get_host_os() == 'Win32':
@@ -72,17 +83,29 @@ Make aos program.\n"
 
         for cmd in cmds:
             if cmd == "clean":
-                if ext_scons_existed:
-                    result = os.system("scons -c") >> 8
+                if opt.board:
+                    if ext_scons_existed:
+                        result = os.system("scons -c --board=%s" % opt.board) >> 8
+                    else:
+                        result = os.system("make clean BOARD=%s" % opt.board) >> 8
                 else:
-                    result = os.system("make clean") >> 8
+                    if ext_scons_existed:
+                        result = os.system("scons -c") >> 8
+                    else:
+                        result = os.system("make clean") >> 8
                 break
             elif cmd == "distclean":
                 self.clearSolutionAndBoard(conf.yoc_path)
-                if ext_scons_existed:
-                    result = os.system("scons -c") >> 8
+                if opt.board:
+                    if ext_scons_existed:
+                        result = os.system("scons -c --board=%s" % opt.board) >> 8
+                    else:
+                        result = os.system("make clean BOARD=%s" % opt.board) >> 8
                 else:
-                    result = os.system("make clean") >> 8
+                    if ext_scons_existed:
+                        result = os.system("scons -c") >> 8
+                    else:
+                        result = os.system("make clean") >> 8
                 break
             elif "@" in cmd:
                 self.saveSolutionAndBoard(conf.yoc_path, cmd)
@@ -100,6 +123,7 @@ Make aos program.\n"
             if len(v) != 2:
                 put_string("Invalid format. Please config it like aos make solution@board -c config")
                 exit(-1)
+            set_specified_board(v[1])
             # update package.yaml of solution: set the specified board as default one
             filename = os.path.join(yoc_path, "solutions", v[0], 'package.yaml')
             if os.path.isfile(filename):
