@@ -33,6 +33,7 @@ class Configure:
         self.branch = 'master'       # manifest.git的branch
         self.init = False
         self.need_auto_init = False
+        self.disable_auto_install = False
 
         self.yoc_path = os.getcwd()
         host_os = get_host_os()
@@ -287,13 +288,18 @@ class YoC:
                         if len(v) > 1:
                             x = re.search('<(.+?)>', v[1], re.M | re.I)
                             if x:
-                                cond = x.group(1)
+                                conds = x.group(1).split(',')
                                 tmp = {}
                                 tmp["comp_name"] = name
                                 tmp["count"] = 0
-                                tmp["condition"] = [cond]
+                                tmp["condition"] = []
+                                for cond in conds:
+                                    cond = cond.strip()
+                                    if cond:
+                                        tmp["condition"].append(cond)
                                 depends.append(tmp)
-                                # print("add depend:%s with cond:%s for %s" % (name, cond, comp.name))
+                                # print("add depend:%s with cond:%s for %s" % (name, conds, comp.name))
+                                # print("%s:%s" % (tmp["comp_name"], tmp["condition"]))
 
         merge_depends = []
         if depends:
@@ -307,15 +313,16 @@ class YoC:
         depends = []
         """ comps are optional dependency list from last layer """
         for comp in comps_list:
-            parent_found = {}
+            parent_found = []
             for parent_name in parent_names:
                 if comp.name == parent_name["comp_name"]:
-                    parent_found = parent_name
-                    break
+                    parent_found.append(parent_name)
+
             if not parent_found:
                 continue
             # if recursive level is >= 64, there should be dead loop, ignore this comp forcely
-            if parent_found["count"] >=64:
+            recur_level = list(map(lambda x: True if x["count"] >= 64 else False, parent_found))
+            if True in recur_level:
                 continue
             for dep_dict in comp.depends:
                 name = list(dep_dict.keys())[0]
@@ -323,13 +330,15 @@ class YoC:
                 """ get mandatory dependency list for this optional component """
                 if (name not in exclude_names) and (cond.find('?') < 0):
                     """ add to the list with the inherrited dependency"""
-                    tmp = {}
-                    tmp["comp_name"] = name
-                    tmp["count"] = parent_found["count"] + 1
-                    tmp["condition"] = parent_found["condition"]
-                    depends.append(tmp)
-                    # print(tmp["count"])
-                    # print("add depend:%s with inherrited cond:%s for %s" % (name, parent_found["condition"], comp.name))
+                    for parent in parent_found:
+                        tmp = {}
+                        tmp["comp_name"] = name
+                        tmp["count"] = parent["count"] + 1
+                        tmp["condition"] = parent["condition"]
+                        depends.append(tmp)
+                        # print(tmp["count"])
+                        # print("add depend:%s with inherrited cond:%s for %s" % (name, parent["condition"], comp.name))
+                        # print("%s:%s" % (tmp["comp_name"], tmp["condition"]))
                 """ get optional dependency list for this optional component """
                 if (name not in exclude_names) and (cond.find('?') >= 0):
                     v = cond.split('?')
@@ -337,17 +346,20 @@ class YoC:
                         x = re.search('<(.+?)>', v[1], re.M | re.I)
                         if x:
                             """ add to the list with (the inherrited dependency && this condition) """
-                            cond = x.group(1)
-                            tmp = {}
-                            tmp["comp_name"] = name
-                            tmp["count"] = parent_found["count"] + 1
-                            if cond not in parent_found["condition"]:
-                                tmp["condition"] = parent_found["condition"] + [cond]
-                            else:
-                                tmp["condition"] = parent_found["condition"]
-                            depends.append(tmp)
-                            # print(tmp["count"])
-                            # print("add depend:%s with inherrited cond:%s and append cond: %s for %s" % (name, parent_found["condition"], cond, comp.name))
+                            conds = x.group(1).split(',')
+                            for parent in parent_found:
+                                tmp = {}
+                                tmp["comp_name"] = name
+                                tmp["count"] = parent["count"] + 1
+                                tmp["condition"] = parent["condition"][:]
+                                for cond in conds:
+                                    cond = cond.strip()
+                                    if cond and cond not in parent["condition"]:
+                                        tmp["condition"].append(cond)
+                                depends.append(tmp)
+                                # print(tmp["count"])
+                                # print("add depend:%s with inherrited cond:%s and append cond: %s for %s" % (name, parent["condition"], conds, comp.name))
+                                # print("%s:%s" % (tmp["comp_name"], tmp["condition"]))
 
         if depends:
             depends += self.get_comp_optional_depends_r(comps_list, depends, exclude_names)
@@ -398,21 +410,32 @@ class YoC:
             if component.path == os.getcwd():
                 component.load_package()
                 if board_name:
-                    if self.components.get(board_name):
-                        component.hw_info.board_name = board_name
-                    else:
+                    component.hw_info.board_name = board_name
+                    if not self.components.get(board_name):
                         put_string("Board component `%s` not found in current workspace, please install it: aos install %s " %(board_name, board_name))
-                        exit(-1)
-                # 根据指定的board_name过滤其他的board组件
+                # 根据指定的board_name过滤其他的board组件；同时确认board_name是否在depends中
                 exclude_names = []
+                bFound = False
                 for name in component.depends:
                     if type(name) == dict:
                         name = list(name.keys())[0]
                     c = self.components.get(name)
                     if c:
                         c.load_package()
-                        if c.type == 'board' and name != component.hw_info.board_name:
-                            exclude_names.append(name)
+                        if c.type == 'board':
+                            if name != component.hw_info.board_name:
+                                exclude_names.append(name)
+                            else:
+                                bFound = True
+                # 添加board_name至component.depends中
+                if not bFound:
+                    for board in component.supported_boards:
+                        name = board
+                        if type(board) == dict:
+                            name = list(board.keys())[0]
+                        if name == board_name:
+                            component.depends.append(board)
+                            break
 
                 components, lost = self.components.get_depend(component, exclude_names, print_depends=print_depends)
                 if lost:
@@ -431,16 +454,19 @@ class YoC:
                 return solution
 
     def auto_install_missing_comp(self, lost_comps):
-        put_string("Try to install missing component...")
-        ret = 0
-        for comp_dict in lost_comps:
-            name = list(comp_dict.keys())[0]
-            cond = list(comp_dict.values())[0]
-            v = cond.split('?')
-            if len(v) > 1:
-                cond = v[0]
-            ret = ret | (os.system("aos-tools install %s -b %s" %(name, cond)) >> 8)
-        return ret
+        if not self.conf.disable_auto_install:
+            put_string("Try to install missing component...")
+            ret = 0
+            for comp_dict in lost_comps:
+                name = list(comp_dict.keys())[0]
+                cond = list(comp_dict.values())[0]
+                v = cond.split('?')
+                if len(v) > 1:
+                    cond = v[0]
+                ret = ret | (os.system("aos-tools install %s -b %s" %(name, cond)) >> 8)
+            return ret
+        else:
+            return 0
 
     def check_cmpt_download(self, name, update=True, force=False):
         if self.components.get(name) and not force:
